# GetBiblesRes


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**bibles** | [**List[Bible]**](Bible.md) |  | 

## Example

```python
from openapi_client.models.get_bibles_res import GetBiblesRes

# TODO update the JSON string below
json = "{}"
# create an instance of GetBiblesRes from a JSON string
get_bibles_res_instance = GetBiblesRes.from_json(json)
# print the JSON string representation of the object
print(GetBiblesRes.to_json())

# convert the object into a dict
get_bibles_res_dict = get_bibles_res_instance.to_dict()
# create an instance of GetBiblesRes from a dict
get_bibles_res_from_dict = GetBiblesRes.from_dict(get_bibles_res_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


